@@ -407,7 +407,7 @@ size_t fread_be_double64(double *destination, int n, FILE *instream){
  ************************************************************************/
 
 
-size_t gzread_int32(int *destination, int n, gzFile *instream){
+size_t gzread_int32(int *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -431,7 +431,7 @@ size_t gzread_int32(int *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_uint32(unsigned int *destination, int n, gzFile *instream){
+size_t gzread_uint32(unsigned int *destination, int n, gzFile instream){
 
 
   size_t result;
@@ -452,7 +452,7 @@ size_t gzread_uint32(unsigned int *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_int16(short *destination, int n, gzFile *instream){
+size_t gzread_int16(short *destination, int n, gzFile instream){
    size_t result;
 
    result = gzread(instream,destination,sizeof(short)*n);
@@ -470,7 +470,7 @@ size_t gzread_int16(short *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_uint16(unsigned short *destination, int n, gzFile *instream){
+size_t gzread_uint16(unsigned short *destination, int n, gzFile instream){
    size_t result;
 
    result = gzread(instream,destination,sizeof(unsigned short)*n);
@@ -489,7 +489,7 @@ size_t gzread_uint16(unsigned short *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_float32(float *destination, int n, gzFile *instream){
+size_t gzread_float32(float *destination, int n, gzFile instream){
 
   size_t result;
 
@@ -506,7 +506,7 @@ size_t gzread_float32(float *destination, int n, gzFile *instream){
   return result;
 }
 
-size_t gzread_char(char *destination, int n, gzFile *instream){
+size_t gzread_char(char *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -522,7 +522,7 @@ size_t gzread_char(char *destination, int n, gzFile *instream){
 }
 
 
-size_t gzread_uchar(unsigned char *destination, int n, gzFile *instream){
+size_t gzread_uchar(unsigned char *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -540,7 +540,7 @@ size_t gzread_uchar(unsigned char *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_double64(double *destination, int n, gzFile *instream){
+size_t gzread_double64(double *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -568,7 +568,7 @@ size_t gzread_double64(double *destination, int n, gzFile *instream){
  ************************************************************************/
 
 
-size_t gzread_be_int32(int *destination, int n, gzFile *instream){
+size_t gzread_be_int32(int *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -592,7 +592,7 @@ size_t gzread_be_int32(int *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_be_uint32(unsigned int *destination, int n, gzFile *instream){
+size_t gzread_be_uint32(unsigned int *destination, int n, gzFile instream){
 
 
   size_t result;
@@ -614,7 +614,7 @@ size_t gzread_be_uint32(unsigned int *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_be_int16(short *destination, int n, gzFile *instream){
+size_t gzread_be_int16(short *destination, int n, gzFile instream){
    size_t result;
 
    result = gzread(instream,destination,sizeof(short)*n);
@@ -630,7 +630,7 @@ size_t gzread_be_int16(short *destination, int n, gzFile *instream){
 }
 
 
-size_t gzread_be_uint16(unsigned short *destination, int n, gzFile *instream){
+size_t gzread_be_uint16(unsigned short *destination, int n, gzFile instream){
    size_t result;
 
    result = gzread(instream,destination,sizeof(unsigned short)*n);
@@ -648,7 +648,7 @@ size_t gzread_be_uint16(unsigned short *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_be_float32(float *destination, int n, gzFile *instream){
+size_t gzread_be_float32(float *destination, int n, gzFile instream){
 
   size_t result;
 
@@ -666,7 +666,7 @@ size_t gzread_be_float32(float *destination, int n, gzFile *instream){
 }
 
 
-size_t gzread_be_char(char *destination, int n, gzFile *instream){
+size_t gzread_be_char(char *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -683,7 +683,7 @@ size_t gzread_be_char(char *destination, int n, gzFile *instream){
 
 
 
-size_t gzread_be_uchar(unsigned char *destination, int n, gzFile *instream){
+size_t gzread_be_uchar(unsigned char *destination, int n, gzFile instream){
 
   size_t result;
   
@@ -699,7 +699,7 @@ size_t gzread_be_uchar(unsigned char *destination, int n, gzFile *instream){
 }
 
 
-size_t gzread_be_double64(double *destination, int n, gzFile *instream){
+size_t gzread_be_double64(double *destination, int n, gzFile instream){
 
   size_t result;
   
